Module profiling

Module profiling 

Structs

LibfuncWeights
Weights per libfunc.
ProcessedProfilingInfo
Full profiling info of a single run. This is the processed info which went through additional processing after collecting the raw data during the run itself.
ProfilingInfo
Profiling info of a single run. This is the raw info — it went through minimal processing, as this is done during the run. To enrich it before viewing/printing, use the ProfilingInfoProcessor.
ProfilingInfoProcessor
A processor for profiling info. Used to process the raw profiling info (basic info collected during the run) into a more detailed profiling info that can also be formatted.
ProfilingInfoProcessorParams
Parameters controlling what profiling info is processed and how, by the ProfilingInfoProcessor.
StackTraceWeights
Weights per stack trace.
UserFunctionWeights
Weights per user function.

Enums

ProfilerConfig
Profiler configuration.

Functions

user_function_idx_by_sierra_statement_idx
Converts a Sierra statement index to the index of the function that contains it (the index in the list in the Sierra program).