pub struct MemBuffer<'a> {
pub ptr: Relocatable,
/* private fields */
}Expand description
A helper struct to continuously write and read from a buffer in the VM memory.
Fields
ptr: RelocatableThe current location of the buffer.
Implementations
Sourceimpl<'a> MemBuffer<'a>
impl<'a> MemBuffer<'a>
Sourcepub fn new(vm: &'a mut dyn VMWrapper, ptr: Relocatable) -> Self
pub fn new(vm: &'a mut dyn VMWrapper, ptr: Relocatable) -> Self
Creates a new buffer.
Sourcepub fn new_segment(vm: &'a mut dyn VMWrapper) -> Self
pub fn new_segment(vm: &'a mut dyn VMWrapper) -> Self
Creates a new segment and returns a buffer wrapping it.
Sourcepub fn next_felt252(&mut self) -> Result<Cow<'_, Felt252>, MemoryError>
pub fn next_felt252(&mut self) -> Result<Cow<'_, Felt252>, MemoryError>
Returns the felt252 value in the current position of the buffer and advances it by one. Fails if the value is not a felt252. Borrows the buffer since a reference is returned.
Sourcepub fn next_usize(&mut self) -> Result<usize, MemoryError>
pub fn next_usize(&mut self) -> Result<usize, MemoryError>
Returns the usize value in the current position of the buffer and advances it by one.
Fails with MemoryError if the value is not a felt252.
Panics if the value is not a usize.
Sourcepub fn next_u128(&mut self) -> Result<u128, MemoryError>
pub fn next_u128(&mut self) -> Result<u128, MemoryError>
Returns the u128 value in the current position of the buffer and advances it by one.
Fails with MemoryError if the value is not a felt252.
Panics if the value is not a u128.
Sourcepub fn next_u64(&mut self) -> Result<u64, MemoryError>
pub fn next_u64(&mut self) -> Result<u64, MemoryError>
Returns the u64 value in the current position of the buffer and advances it by one.
Fails with MemoryError if the value is not a felt252.
Panics if the value is not a u64.
Sourcepub fn next_u256(&mut self) -> Result<BigUint, MemoryError>
pub fn next_u256(&mut self) -> Result<BigUint, MemoryError>
Returns the u256 value encoded starting from the current position of the buffer and advances
it by two.
Fails with MemoryError if any of the next two values are not felt252s.
Panics if any of the next two values are not u128.
Sourcepub fn next_addr(&mut self) -> Result<Relocatable, MemoryError>
pub fn next_addr(&mut self) -> Result<Relocatable, MemoryError>
Returns the address value in the current position of the buffer and advances it by one. Fails if the value is not an address.
Sourcepub fn next_arr(&mut self) -> Result<Vec<Felt252>, HintError>
pub fn next_arr(&mut self) -> Result<Vec<Felt252>, HintError>
Returns the array of integer values pointed to by the two next addresses in the buffer and advances it by two. Will fail if the two values are not addresses or if the addresses do not point to an array of integers.
Sourcepub fn next_fixed_size_arr_pointer(
&mut self,
size: usize,
) -> Result<Vec<Felt252>, HintError>
pub fn next_fixed_size_arr_pointer( &mut self, size: usize, ) -> Result<Vec<Felt252>, HintError>
Returns the array of integer values pointed to by the next address in the buffer and with a fixed size and advances the buffer by one. Will fail if the next value is not an address or if the address does not point to an array of integers.
Sourcepub fn write<T: Into<MaybeRelocatable>>(
&mut self,
value: T,
) -> Result<(), MemoryError>
pub fn write<T: Into<MaybeRelocatable>>( &mut self, value: T, ) -> Result<(), MemoryError>
Writes a value to the current position of the buffer and advances it by one.
Sourcepub fn write_data<T: Into<MaybeRelocatable>, Data: Iterator<Item = T>>(
&mut self,
data: Data,
) -> Result<(), MemoryError>
pub fn write_data<T: Into<MaybeRelocatable>, Data: Iterator<Item = T>>( &mut self, data: Data, ) -> Result<(), MemoryError>
Writes an iterator of values starting from the current position of the buffer and advances it to after the end of the written value.
Sourcepub fn write_arr<T: Into<MaybeRelocatable>, Data: Iterator<Item = T>>(
&mut self,
data: Data,
) -> Result<(), MemoryError>
pub fn write_arr<T: Into<MaybeRelocatable>, Data: Iterator<Item = T>>( &mut self, data: Data, ) -> Result<(), MemoryError>
Writes an array into a new segment and writes the start and end pointers to the current position of the buffer. Advances the buffer by two.