Full profiling info of a single run. This is the processed info which went through additional
processing after collecting the raw data during the run itself.
Profiling info of a single run. This is the raw info — it went through minimal processing, as
this is done during the run. To enrich it before viewing/printing, use the
ProfilingInfoProcessor.
A processor for profiling info. Used to process the raw profiling info (basic info collected
during the run) into a more detailed profiling info that can also be formatted.