Struct cairo_lang_runner::SierraCasmRunner
source · pub struct SierraCasmRunner { /* private fields */ }Expand description
Runner enabling running a Sierra program on the vm.
Implementations
sourceimpl SierraCasmRunner
impl SierraCasmRunner
pub fn new( sierra_program: Program, metadata_config: Option<MetadataComputationConfig>, starknet_contracts_info: OrderedHashMap<Felt252, ContractInfo> ) -> Result<Self, RunnerError>
sourcepub fn run_function_with_starknet_context(
&self,
func: &Function,
args: &[Arg],
available_gas: Option<usize>,
starknet_state: StarknetState
) -> Result<RunResultStarknet, RunnerError>
pub fn run_function_with_starknet_context( &self, func: &Function, args: &[Arg], available_gas: Option<usize>, starknet_state: StarknetState ) -> Result<RunResultStarknet, RunnerError>
Runs the vm starting from a function in the context of a given starknet state.
sourcepub fn run_function<'a, Instructions>(
&self,
func: &Function,
hint_processor: &mut dyn HintProcessor,
hints_dict: HashMap<usize, Vec<HintParams>>,
instructions: Instructions,
builtins: Vec<BuiltinName>
) -> Result<RunResult, RunnerError>where
Instructions: Iterator<Item = &'a Instruction> + Clone,
pub fn run_function<'a, Instructions>( &self, func: &Function, hint_processor: &mut dyn HintProcessor, hints_dict: HashMap<usize, Vec<HintParams>>, instructions: Instructions, builtins: Vec<BuiltinName> ) -> Result<RunResult, RunnerError>where Instructions: Iterator<Item = &'a Instruction> + Clone,
Runs the vm starting from a function with custom hint processor. Function may have implicits, but no other ref params. The cost of the function is deducted from available_gas before the execution begins.
sourcepub fn find_function(&self, name_suffix: &str) -> Result<&Function, RunnerError>
pub fn find_function(&self, name_suffix: &str) -> Result<&Function, RunnerError>
Finds first function ending with name_suffix.
sourcepub fn create_entry_code(
&self,
func: &Function,
args: &[Arg],
initial_gas: usize
) -> Result<(Vec<Instruction>, Vec<BuiltinName>), RunnerError>
pub fn create_entry_code( &self, func: &Function, args: &[Arg], initial_gas: usize ) -> Result<(Vec<Instruction>, Vec<BuiltinName>), RunnerError>
Returns the instructions to add to the beginning of the code to successfully call the main function, as well as the builtins required to execute the program.
sourcepub fn get_initial_available_gas(
&self,
func: &Function,
available_gas: Option<usize>
) -> Result<usize, RunnerError>
pub fn get_initial_available_gas( &self, func: &Function, available_gas: Option<usize> ) -> Result<usize, RunnerError>
Returns the initial value for the gas counter. If available_gas is None returns 0.
Creates a list of instructions that will be appended to the program’s bytecode.
pub fn get_casm_program(&self) -> &CairoProgram